@@ -66,12 +66,14 @@ bool KateCommands::CoreCommands::help(KTextEditor::View *, const QString &cmd, Q
     } else if (realcmd == QLatin1String("comment")) {
         msg = i18n(
             "<p>comment</p>"
-            "<p>Inserts comment markers to make the selection or selected lines or current line a comment according to the text format as defined by the syntax highlight definition for the document.</p>");
+            "<p>Inserts comment markers to make the selection or selected lines or current line a comment according to the text format as defined by the "
+            "syntax highlight definition for the document.</p>");
         return true;
     } else if (realcmd == QLatin1String("uncomment")) {
         msg = i18n(
             "<p>uncomment</p>"
-            "<p>Removes comment markers from the selection or selected lines or current line according to the text format as defined by the syntax highlight definition for the document.</p>");
+            "<p>Removes comment markers from the selection or selected lines or current line according to the text format as defined by the syntax highlight "
+            "definition for the document.</p>");
         return true;
     } else if (realcmd == QLatin1String("goto")) {
         msg = i18n(
@@ -178,7 +180,8 @@ bool KateCommands::CoreCommands::help(KTextEditor::View *, const QString &cmd, Q
     } else if (realcmd == QLatin1String("set-highlight")) {
         msg = i18n(
             "<p>set-highlight <b>highlight</b></p>"
-            "<p>Sets the syntax highlighting system for the document. The argument must be a valid highlight name, as seen in the Tools → Highlighting menu. This command provides an autocompletion list for its argument.</p>");
+            "<p>Sets the syntax highlighting system for the document. The argument must be a valid highlight name, as seen in the Tools → Highlighting menu. "
+            "This command provides an autocompletion list for its argument.</p>");
         return true;
     } else if (realcmd == QLatin1String("set-mode")) {
         msg = i18n(
@@ -202,10 +205,10 @@ bool KateCommands::CoreCommands::help(KTextEditor::View *, const QString &cmd, Q
 
 bool KateCommands::CoreCommands::exec(KTextEditor::View *view, const QString &_cmd, QString &errorMsg, const KTextEditor::Range &range)
 {
-#define KCC_ERR(s)                                                                                                                                                                                                                             \
-    {                                                                                                                                                                                                                                          \
-        errorMsg = s;                                                                                                                                                                                                                          \
-        return false;                                                                                                                                                                                                                          \
+#define KCC_ERR(s)                                                                                                                                             \
+    {                                                                                                                                                          \
+        errorMsg = s;                                                                                                                                          \
+        return false;                                                                                                                                          \
     }
     // cast it hardcore, we know that it is really a kateview :)
     KTextEditor::ViewPrivate *v = static_cast<KTextEditor::ViewPrivate *>(view);
@@ -215,11 +218,7 @@ bool KateCommands::CoreCommands::exec(KTextEditor::View *view, const QString &_c
     }
 
     // create a list of args
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList args(_cmd.split(QRegularExpression(QStringLiteral("\\s+")), QString::SkipEmptyParts));
-#else
     QStringList args(_cmd.split(QRegularExpression(QStringLiteral("\\s+")), Qt::SkipEmptyParts));
-#endif
     QString cmd(args.takeFirst());
 
     // ALL commands that takes no arguments.
@@ -257,7 +256,8 @@ bool KateCommands::CoreCommands::exec(KTextEditor::View *view, const QString &_c
         }
         return true;
     } else if (cmd == QLatin1String("fold")) {
-        return (v->textFolding().newFoldingRange(range.isValid() ? range : v->selectionRange(), Kate::TextFolding::Persistent | Kate::TextFolding::Folded) != -1);
+        return (v->textFolding().newFoldingRange(range.isValid() ? range : v->selectionRange(), Kate::TextFolding::Persistent | Kate::TextFolding::Folded)
+                != -1);
     } else if (cmd == QLatin1String("tfold")) {
         return (v->textFolding().newFoldingRange(range.isValid() ? range : v->selectionRange(), Kate::TextFolding::Folded) != -1);
     } else if (cmd == QLatin1String("unfold")) {
@@ -273,7 +273,7 @@ bool KateCommands::CoreCommands::exec(KTextEditor::View *view, const QString &_c
         if (range.isValid()) {
             v->doc()->editStart();
             for (int line = range.start().line(); line <= range.end().line(); line++) {
-                v->doc()->comment(v, line, 0, 1);
+                v->doc()->comment(v, line, 0, KTextEditor::DocumentPrivate::Comment);
             }
             v->doc()->editEnd();
         } else {
@@ -284,7 +284,7 @@ bool KateCommands::CoreCommands::exec(KTextEditor::View *view, const QString &_c
         if (range.isValid()) {
             v->doc()->editStart();
             for (int line = range.start().line(); line <= range.end().line(); line++) {
-                v->doc()->comment(v, line, 0, -1);
+                v->doc()->comment(v, line, 0, KTextEditor::DocumentPrivate::UnComment);
             }
             v->doc()->editEnd();
         } else {
@@ -334,7 +334,8 @@ bool KateCommands::CoreCommands::exec(KTextEditor::View *view, const QString &_c
         }
     }
     // ALL commands that takes exactly one integer argument.
-    else if (cmd == QLatin1String("set-tab-width") || cmd == QLatin1String("set-indent-width") || cmd == QLatin1String("set-word-wrap-column") || cmd == QLatin1String("goto")) {
+    else if (cmd == QLatin1String("set-tab-width") || cmd == QLatin1String("set-indent-width") || cmd == QLatin1String("set-word-wrap-column")
+             || cmd == QLatin1String("goto")) {
         // find a integer value > 0
         if (args.isEmpty()) {
             KCC_ERR(i18n("Missing argument. Usage: %1 <value>", cmd));
@@ -381,8 +382,10 @@ bool KateCommands::CoreCommands::exec(KTextEditor::View *view, const QString &_c
     }
 
     // ALL commands that takes 1 boolean argument.
-    else if (cmd == QLatin1String("set-icon-border") || cmd == QLatin1String("set-folding-markers") || cmd == QLatin1String("set-indent-pasted-text") || cmd == QLatin1String("set-line-numbers") || cmd == QLatin1String("set-replace-tabs") ||
-             cmd == QLatin1String("set-show-tabs") || cmd == QLatin1String("set-word-wrap") || cmd == QLatin1String("set-wrap-cursor") || cmd == QLatin1String("set-replace-tabs-save") || cmd == QLatin1String("set-show-indent")) {
+    else if (cmd == QLatin1String("set-icon-border") || cmd == QLatin1String("set-folding-markers") || cmd == QLatin1String("set-indent-pasted-text")
+             || cmd == QLatin1String("set-line-numbers") || cmd == QLatin1String("set-replace-tabs") || cmd == QLatin1String("set-show-tabs")
+             || cmd == QLatin1String("set-word-wrap") || cmd == QLatin1String("set-wrap-cursor") || cmd == QLatin1String("set-replace-tabs-save")
+             || cmd == QLatin1String("set-show-indent")) {
         if (args.isEmpty()) {
             KCC_ERR(i18n("Usage: %1 on|off|1|0|true|false", cmd));
         }
@@ -436,9 +439,10 @@ bool KateCommands::CoreCommands::supportsRange(const QString &range)
 {
     static QStringList l;
 
-    if (l.isEmpty())
-        l << QStringLiteral("indent") << QStringLiteral("unindent") << QStringLiteral("cleanindent") << QStringLiteral("comment") << QStringLiteral("uncomment") << QStringLiteral("kill-line") << QStringLiteral("fold")
-          << QStringLiteral("tfold");
+    if (l.isEmpty()) {
+        l << QStringLiteral("indent") << QStringLiteral("unindent") << QStringLiteral("cleanindent") << QStringLiteral("comment") << QStringLiteral("uncomment")
+          << QStringLiteral("kill-line") << QStringLiteral("fold") << QStringLiteral("tfold");
+    }
 
     return l.contains(range);
 }
@@ -450,7 +454,8 @@ KCompletion *KateCommands::CoreCommands::completionObject(KTextEditor::View *vie
     if (cmd == QLatin1String("set-highlight")) {
         QStringList l;
         l.reserve(KateHlManager::self()->modeList().size());
-        for (const auto &hl : KateHlManager::self()->modeList()) {
+        const auto modeList = KateHlManager::self()->modeList();
+        for (const auto &hl : modeList) {
             l << hl.name();
         }
 
@@ -501,8 +506,8 @@ bool KateCommands::Character::exec(KTextEditor::View *view, const QString &_cmd,
     QString cmd = _cmd;
 
     // hex, octal, base 9+1
-    QRegularExpression num(QStringLiteral("^char *(0?x[0-9A-Fa-f]{1,4}|0[0-7]{1,6}|[0-9]{1,5})$"));
-    QRegularExpressionMatch match = num.match(cmd);
+    static const QRegularExpression num(QStringLiteral("^char *(0?x[0-9A-Fa-f]{1,4}|0[0-7]{1,6}|[0-9]{1,5})$"));
+    const QRegularExpressionMatch match = num.match(cmd);
     if (!match.hasMatch()) {
         return false;
     }
